==> mod_snmp-1.0.tar.gz: mod_snmp-1.0/src/nk_snmp.h <==
/*
** nk_snmp Header File	(Public or Private)
*/


/***********************************************************************
** Standard header preamble.  Ensure singular inclusion, setup for
** function prototypes and c++ inclusion
*/

#ifndef NK_SNMP_H

#define NK_SNMP_H 1

#if defined(__STDC__) || defined(__cplusplus)
#  define __ANSI_PROTO(x)       x
#else
#  define __ANSI_PROTO(x)       ()
#endif

#ifdef __cplusplus
extern "C" {
#endif



/***********************************************************************
** Macro Definitions
*/

/* SNMP Operations */

#define	NK_SNMP_GET			1
#define	NK_SNMP_GETNEXT			2
#define NK_SNMP_SET			3

/* Error Codes */

#define	NK_SNMP_ERR_OK			0
#define	NK_SNMP_ERR_SESSION		-1
#define NK_SNMP_ERR_NO_OID		-2
#define NK_SNMP_ERR_BAD_OID		-3
#define	NK_SNMP_ERR_BAD_OP		-4
#define	NK_SNMP_ERR_BAD_PDU		-5
#define	NK_SNMP_ERR_GENERAL		-6
#define	NK_SNMP_ERR_UNKNOWN_HOST	-7
#define	NK_SNMP_ERR_TIMEOUT		-8

#define	NK_SNMP_TYPE_COUNTER32		1
#define	NK_SNMP_TYPE_COUNTER64		2
#define	NK_SNMP_TYPE_OCTET_STR		3
#define	NK_SNMP_TYPE_OBJ_ID		4

/* Trap types */
#define NK_SNMP_TRAP_COLDSTART		0
#define NK_SNMP_TRAP_WARMSTART		1
#define NK_SNMP_TRAP_LINKDOWN		2
#define NK_SNMP_TRAP_LINKUP		3
#define NK_SNMP_TRAP_AUTHFAILURE	4
#define NK_SNMP_TRAP_EGPNEIGHBORLOSS	5
#define NK_SNMP_TRAP_ENTERPRISESPECIFIC	6


/* SNMP Base Types */
#define NK_SNMP_UNKNOWN_TYPE		0
#define NK_SNMP_INT_TYPE		1
#define NK_SNMP_UINT_TYPE		2
#define NK_SNMP_INT64_TYPE		3
#define NK_SNMP_IPV4_TYPE		4
#define NK_SNMP_OCTET_STR_TYPE		5
#define NK_SNMP_OID_TYPE		6


/***********************************************************************
** Type Definitions
*/

/* 64 bit type for counters */

typedef struct {
	unsigned long	high,
			low;
} nk_snmp_64;


/* NK's abstraction of a variable */
typedef struct nk_snmp_var_t{
	char		oid[NK_MAX_SNMP_OID_LEN],
			var[NK_MAX_SNMP_VAR_LEN];
	int		var_type,
			var_data_len,
			oid_len;
	char		text_val[NK_MAX_SNMP_TEXT_LEN],
			byte_val[NK_MAX_SNMP_TEXT_LEN],
			ipv4_val[4];
	int		int_val;
	u_int		uint_val;
	nk_snmp_64	int64_val;
	struct nk_snmp_var_t	*next;
} nk_snmp_var;



/* NK's abstraction of a received trap */
typedef struct {
	int		trap_type,
			enterprise_type,
			num_variables,
			enterprise_len;
	u_char		source_addr[4];
	char		source_host[NK_MAX_HOSTNAME_LEN],
			enterprise_oid[NK_MAX_SNMP_OID_LEN],
			enterprise_var[NK_MAX_SNMP_VAR_LEN];
	nk_snmp_var	*variables;
} nk_snmp_trap;


/* NK's abstraction of a GET/GET_NEXT result */
typedef struct {
	int		result,
			operation,
			num_variables;
	char		source_addr[4],
			source_host[NK_MAX_HOSTNAME_LEN];
	nk_snmp_var	*variables;
	void		*data;
} nk_snmp_result;


/***********************************************************************
** Function Prototypes
*/

int nkSnmpAddVariable __ANSI_PROTO((char *, char *, char*));
int nkSnmpTrapOpen __ANSI_PROTO(());
int nkSnmpErrorCode __ANSI_PROTO(());

void nkSnmpClose __ANSI_PROTO((char *));
void nkSnmpFreePDU __ANSI_PROTO((char *));
void nkSnmpPrintError __ANSI_PROTO((FILE*));

char *nkSnmpOpen __ANSI_PROTO((char *, char *));
char *nkSnmpCreatePDU __ANSI_PROTO((int));
char *nkSnmpPrintOid __ANSI_PROTO((char *, int));

nk_snmp_result *nkSnmpRequest __ANSI_PROTO((char *, char *));
nk_snmp_trap *nkSnmpTrapRead __ANSI_PROTO((int));

/***********************************************************************
** Standard header file footer.  
*/

#ifdef __cplusplus
	}
#endif /* __cplusplus */
#endif /* file inclusion */

==> mod_snmp-1.2.tar.gz: mod_snmp-1.2/src/nk_snmp.h <==
/*
** nk_snmp Header File	(Public or Private)
*/


/***********************************************************************
** Standard header preamble.  Ensure singular inclusion, setup for
** function prototypes and c++ inclusion
*/

#ifndef NK_SNMP_H

#define NK_SNMP_H 1

#if defined(__STDC__) || defined(__cplusplus)
#  define __ANSI_PROTO(x)       x
#else
#  define __ANSI_PROTO(x)       ()
#endif

#ifdef __cplusplus
extern "C" {
#endif



/***********************************************************************
** Macro Definitions
*/

/* SNMP Operations */

#define	NK_SNMP_GET			1
#define	NK_SNMP_GETNEXT			2
#define NK_SNMP_GETBULK			3
#define NK_SNMP_SET			4

/* SNMP Versions */
#define NK_SNMP_VERSION_1		1
#define NK_SNMP_VERSION_2		2

/* Error Codes */

#define	NK_SNMP_ERR_OK			0
#define	NK_SNMP_ERR_SESSION		-2001
#define NK_SNMP_ERR_NO_OID		-2002
#define NK_SNMP_ERR_BAD_OID		-2003
#define	NK_SNMP_ERR_BAD_OP		-2004
#define	NK_SNMP_ERR_BAD_PDU		-2005
#define	NK_SNMP_ERR_GENERAL		-2006
#define	NK_SNMP_ERR_UNKNOWN_HOST	-2007
#define	NK_SNMP_ERR_TIMEOUT		-2008
#define NK_SNMP_ERR_NO_ACCESS		6

#define	NK_SNMP_TYPE_COUNTER32		1
#define	NK_SNMP_TYPE_COUNTER64		2
#define	NK_SNMP_TYPE_OCTET_STR		3
#define	NK_SNMP_TYPE_OBJ_ID		4

/* Trap types */
#define NK_SNMP_TRAP_COLDSTART		0
#define NK_SNMP_TRAP_WARMSTART		1
#define NK_SNMP_TRAP_LINKDOWN		2
#define NK_SNMP_TRAP_LINKUP		3
#define NK_SNMP_TRAP_AUTHFAILURE	4
#define NK_SNMP_TRAP_EGPNEIGHBORLOSS	5
#define NK_SNMP_TRAP_ENTERPRISESPECIFIC	6


/* SNMP Base Types */
#define NK_SNMP_UNKNOWN_TYPE		0
#define NK_SNMP_INT_TYPE		1
#define NK_SNMP_UINT_TYPE		2
#define NK_SNMP_INT64_TYPE		3
#define NK_SNMP_IPV4_TYPE		4
#define NK_SNMP_OCTET_STR_TYPE		5
#define NK_SNMP_OID_TYPE		6


/***********************************************************************
** Type Definitions
*/

/* 64 bit type for counters */

typedef struct {
	unsigned long	high,
			low;
} nk_snmp_64;


/* NK's abstraction of a variable */
typedef struct nk_snmp_var_t{
	char		oid[NK_MAX_SNMP_OID_LEN],
			var[NK_MAX_SNMP_VAR_LEN];
	int		var_type,
			var_data_len,
			oid_len;
	char		text_val[NK_MAX_SNMP_TEXT_LEN],
			byte_val[NK_MAX_SNMP_TEXT_LEN],
			ipv4_val[4];
	int		int_val;
	u_int		uint_val;
	nk_snmp_64	int64_val;
	struct nk_snmp_var_t	*next;
} nk_snmp_var;



/* NK's abstraction of a received trap */
typedef struct {
	int		trap_type,
			enterprise_type,
			num_variables,
			enterprise_len;
	u_char		source_addr[4];
	char		source_host[NK_MAX_HOSTNAME_LEN],
			enterprise_oid[NK_MAX_SNMP_OID_LEN],
			enterprise_var[NK_MAX_SNMP_VAR_LEN];
	nk_snmp_var	*variables;
} nk_snmp_trap;


/* NK's abstraction of a GET/GET_NEXT result */
typedef struct {
	int		result,
			operation,
			num_variables;
	char		source_addr[4],
			source_host[NK_MAX_HOSTNAME_LEN];
	nk_snmp_var	*variables;
	void		*data;
} nk_snmp_result;


/***********************************************************************
** Function Prototypes
*/

int nkSnmpAddVariable __ANSI_PROTO((char *, char *, char*));
int nkSnmpTrapOpen __ANSI_PROTO(());
int nkSnmpErrorCode __ANSI_PROTO(());
int nkSnmpSetVersion __ANSI_PROTO((char *, int));
int nkSnmpSetMaxRepeat __ANSI_PROTO((char *, int));

void nkSnmpClose __ANSI_PROTO((char *));
void nkSnmpFreePDU __ANSI_PROTO((char *));
void nkSnmpPrintError __ANSI_PROTO((FILE*));

char *nkSnmpOpen __ANSI_PROTO((char *, char *));
char *nkSnmpCreatePDU __ANSI_PROTO((int));
char *nkSnmpPrintOid __ANSI_PROTO((char *, int));
char *nkSnmpGetError __ANSI_PROTO(());

nk_snmp_result *nkSnmpRequest __ANSI_PROTO((char *, char *));
nk_snmp_trap *nkSnmpTrapRead __ANSI_PROTO((int));

/***********************************************************************
** Standard header file footer.  
*/

#ifdef __cplusplus
	}
#endif /* __cplusplus */
#endif /* file inclusion */
